@@ -20,6 +20,7 @@ class HistoryLogService(object):
         self.archive_service = request.find_service(
             IPaymentArchiveService
         )
+        self.dbsession = request.dbsession
 
     def record(self, action, invoice, payment):
         self.logger.debug("Recording an action")
@@ -33,14 +34,14 @@ class HistoryDBService(HistoryLogService):
     Service logging datas in a database using a specific connexion
     """
 
-    def get_previous_entry_hash(self, dbsession):
+    def get_previous_entry_hash(self):
         """
         Produce a hash of the csv representation of the previous history entry
 
         :param obj dbsession: The current database session
         :rtype: str
         """
-        previous_entry = dbsession.query(
+        previous_entry = self.dbsession.query(
             EndiPaymentHistory
         ).order_by(desc(EndiPaymentHistory.created_at)).first()
 
@@ -52,35 +53,38 @@ class HistoryDBService(HistoryLogService):
         return result
 
     def record(self, action, invoice, payment):
+        """
+        Record an action on a payment
+
+        1- Record the action
+        2- If an archive service exists, creates an archive
+
+        :param str action: The type of action
+        :param obj invoice: The related Invoice instance
+        :param obj payment: The related payment object
+        """
         self.logger.info("Recording an action")
         self.logger.info("Action : %s" % action)
         self.logger.info("User : %s" % self.request.user)
         self.logger.info("Invoice id : %s" % invoice.id)
         self.logger.info("It's production mode")
 
-        from endi_payment.database import LocalSessionContext
-        with LocalSessionContext() as dbsession:
-            previous_entry_hash = self.get_previous_entry_hash(dbsession)
-            record = EndiPaymentHistory(
-                action_type=action,
-                payment_id=payment.id,
-                mode=payment.mode,
-                amount=payment.amount,
-                bank_remittance_id=payment.bank_remittance_id,
-                date=payment.date,
-                invoice_id=invoice.id,
-                invoice_pdf_file_hash=invoice.pdf_file_hash,
-                bank_cg=payment.bank.compte_cg,
-                tva_value=payment.tva.value,
-                user_login=self.request.user.login.login,
-                previous_entry_hash=previous_entry_hash,
-            )
-            dbsession.add(record)
-            dbsession.flush()
-            archive_seal = self.archive_service.archive(record)
-            if archive_seal is not None:
-                dbsession.add(archive_seal)
-            else:
-                self.logger.debug("No archive seal was produced")
-
+        previous_entry_hash = self.get_previous_entry_hash()
+        record = EndiPaymentHistory(
+            action_type=action,
+            payment_id=payment.id,
+            mode=payment.mode,
+            amount=payment.amount,
+            bank_remittance_id=payment.bank_remittance_id,
+            date=payment.date,
+            invoice_id=invoice.id,
+            invoice_pdf_file_hash=invoice.pdf_file_hash,
+            bank_cg=payment.bank.compte_cg,
+            tva_value=payment.tva.value,
+            user_login=self.request.user.login.login,
+            previous_entry_hash=previous_entry_hash,
+        )
+        self.dbsession.add(record)
+        self.dbsession.flush()
+        self.archive_service.archive(record)
         self.logger.info("Recorded")
