@@ -13,6 +13,7 @@ from sqlalchemy import (
     Text,
     ForeignKey,
 )
+from sqlalchemy.orm import relationship
 from sqla_inspect.ascii import force_encoding
 from endi_base.models.base import default_table_args
 from endi_payment.database import ModelBase
@@ -47,6 +48,13 @@ class EndiPaymentHistory(ModelBase):
     user_login = Column(String(64), nullable=False)
     # The previous entry's md5sum
     previous_entry_hash = Column(String(255), nullable=False)
+    endi_payment_archive_seal = relationship(
+        "EndiPaymentArchiveSeal",
+        primaryjoin="EndiPaymentHistory.id=="
+        "EndiPaymentArchiveSeal.endi_payment_history_id",
+        uselist=False,
+        back_populates="endi_payment_history"
+    )
 
     def as_csv(self):
         """
@@ -103,5 +111,13 @@ class EndiPaymentArchiveSeal(ModelBase):
     __table_args__ = default_table_args
     id = Column(Integer, primary_key=True)
     created_at = Column(DateTime, default=datetime.datetime.now)
+    archive_type = Column(String(20), default='local')
     remote_identification_key = Column(Text(), nullable=False)
     endi_payment_history_id = Column(ForeignKey('endi_payment_history.id'))
+
+    endi_payment_history = relationship(
+        EndiPaymentHistory,
+        primaryjoin="EndiPaymentHistory.id=="
+        "EndiPaymentArchiveSeal.endi_payment_history_id",
+        back_populates="endi_payment_archive_seal"
+    )
